Index: trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h
===================================================================
--- trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h	(revision 884)
+++ trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h	(revision 885)
@@ -19,7 +19,7 @@
 //=
 //= $RCSfile: creadparam.h,v $
-//= $Revision: 1.8 $
+//= $Revision: 1.9 $
 //= $Author: blanch $ 
-//= $Date: 2001-03-05 10:44:44 $
+//= $Date: 2001-07-19 09:29:02 $
 //=
 //=//////////////////////////////////////////////////////////////////////
@@ -151,5 +151,5 @@
 T(nsb_mean),        /* mean value of NSB contribution per pixel */ \
 T(nsb_directory),   /* database for the NSB  */ \
-T(threshold),       /* value of q0 for trigger */ \
+T(pixel_thres),     /* value of q0 for trigger for a given pixel */ \
 T(tail_cut),        /* value of tail cut (t0) */ \
 T(islands_on),      /* DO count islands */ \
@@ -222,5 +222,4 @@
 char *get_nsb_directory(void);
 int get_nsb(float *n, int *m);
-float get_threshold(void);
 float get_tail_cut(void);
 int get_islands_cut(int *n);
@@ -249,4 +248,6 @@
 int get_Trigger_Loop(int *lt, int *ut, int *lm, int *um, int *lg, int *ug);
 void get_Trigger_Single(float *t, int *m, int *g);
+void get_threshold(float *t);
+int get_indi_thres_pixel(void);
 //!@}
 
@@ -264,4 +265,7 @@
 /*
  * $Log: not supported by cvs2svn $
+ * Revision 1.8  2001/03/05 10:44:44  blanch
+ * Header file of creadparam.cxx version 1.9
+ *
  * Revision 1.7  2001/02/23 10:56:10  magicsol
  * Header file for creadparam.cxx version 1.8
